import { ActionRendererParams } from '@genesislcap/grid-pro';
import { AppIntent } from '@finos/fdc3';
import { Channel } from '@finos/fdc3';
import { Container } from '@microsoft/fast-foundation';
import { Context } from '@finos/fdc3';
import { ContextHandler } from '@finos/fdc3';
import { ElementStyles } from '@microsoft/fast-element';
import { FASTElement } from '@genesislcap/web-core';
import { FoundationElement } from '@microsoft/fast-foundation';
import { FoundationElementRegistry } from '@microsoft/fast-foundation';
import { ICellRendererComp } from '@ag-grid-community/core';
import { ICellRendererParams } from '@ag-grid-community/core';
import { IntentResolution } from '@finos/fdc3';
import { Intents } from '@finos/fdc3';
import { InterfaceSymbol } from '@microsoft/fast-foundation';
import { OverrideFoundationElementDefinition } from '@microsoft/fast-foundation';
import { ViewTemplate } from '@microsoft/fast-element';

/**
 * @public
 */
export declare const baseFdc3Components: {
    foundationGridProRaiseIntentActionRenderer: (overrideDefinition?: OverrideFoundationElementDefinition<    {
    baseName: string;
    styles: ElementStyles;
    template: ViewTemplate<Fdc3GridActionRaiseIntent, any>;
    }>) => FoundationElementRegistry<    {
    baseName: string;
    styles: ElementStyles;
    template: ViewTemplate<Fdc3GridActionRaiseIntent, any>;
    }, Fdc3GridActionRaiseIntent>;
    Fdc3ChannelEvent: typeof Fdc3ChannelEvent;
    register(container?: Container, ...rest: any[]): void;
};

/**
 * The FDC3 implementation.
 * @internal
 */
export declare class DefaultFDC3 implements FDC3 {
    isReady: boolean;
    constructor();
    private connect;
    addIntentListeners(listeners: Map<FDC3Intents, FDC3ContextHandler>): void;
    findIntent(intent: FDC3Intents, context?: FDC3Context): Promise<FDC3AppIntent>;
    findIntentsByContext(context: FDC3Context): Promise<FDC3AppIntent[]>;
    raiseIntent(context: FDC3Context, intent?: FDC3Intents): Promise<FDC3IntentResolution>;
    joinChannel(channelId: string): Promise<void>;
    getOrCreateChannel(channelId: string): Promise<FDC3Channel>;
    broadcastOnChannel(channelName: string, type: string, payload: any): Promise<void>;
    broadcastOnChannelEventHandler(channelName: string, type: string): Promise<(e: any) => Promise<void>>;
}

/**
 * The FDC3 API interface.
 * @public
 */
export declare interface FDC3 {
    /**
     * Whether the FDC3 API is ready.
     * @public
     */
    isReady: boolean;
    /**
     * Adds intent listeners for the specified intents.
     * @public
     * @param listeners - The intent listeners to add.
     */
    addIntentListeners(listeners: Map<FDC3Intents, FDC3ContextHandler>): void;
    /**
     * Finds an app that supports the specified intent.
     * @public
     * @param intent - The intent to find an app for.
     * @param context - The context to use.
     * @returns A promise that resolves with the app and its metadata.
     */
    findIntent(intent: FDC3Intents, context?: FDC3Context): Promise<FDC3AppIntent>;
    /**
     * Finds all the intents supported by the specified context.
     * @public
     * @param context - The context to use.
     * @returns A promise that resolves with an array of all matching intents and their metadata.
     */
    findIntentsByContext(context: FDC3Context): Promise<FDC3AppIntent[]>;
    /**
     * Raises the specified intent with the specified context.
     * @public
     * @param context - The context to use.
     * @param intent - The intent to raise.
     * @returns A promise that resolves with the result of the intent resolution.
     */
    raiseIntent(context: FDC3Context, intent?: FDC3Intents): Promise<FDC3IntentResolution>;
    /**
     * Joins the specified channel.
     * @public
     * @param channelId - The ID of the channel to join.
     * @returns A promise that resolves when the join is successful.
     */
    joinChannel(channelId: string): Promise<void>;
    /**
     * Gets or creates the specified channel.
     * @public
     * @param  channelId - The ID of the channel to get or create.
     * @returns A promise that resolves with the channel object.
     */
    getOrCreateChannel(channelId: string): Promise<FDC3Channel>;
    /**
     * Broadcasts a message on a given channel with a given type
     * @param channelName - name of the channel
     * @param type - type of the channel
     * @param payload - payload sent to the channel
     */
    broadcastOnChannel(channelName: string, type: string, payload: any): Promise<void>;
    /**
     * Helper function to broadcast message on channel in response to dispatched event
     * @param channelName - name of the channel
     * @param type - type of the channel
     */
    broadcastOnChannelEventHandler(channelName: string, type: string): Promise<(e: any) => Promise<void>>;
}

/**
 * The DI token for the FDC3 interface.
 * @internal
 */
export declare const FDC3: InterfaceSymbol<FDC3>;

/**
 * The AG Action Renderer Styles.
 * @public
 */
export declare const fdc3AgActionRendererStyles: ElementStyles;

/**
 * @public
 */
export declare interface FDC3AppIntent extends AppIntent {
}

/**
 * @public
 */
export declare interface FDC3Channel extends Channel {
}

/**
 * fdc3-channel-event
 * @internal
 */
export declare class Fdc3ChannelEvent extends FASTElement {
    fdc3: FDC3;
    eventName: string;
    channelType: string;
    channelName: string;
    connectedCallback(): void;
    disconnectedCallback(): void;
    private sendEventOnChannel;
}

/**
 * @public
 */
export declare interface FDC3Context extends Context {
}

/**
 * @public
 */
export declare type FDC3ContextHandler = ContextHandler;

/**
 * The AG Action Renderer element.
 * @public
 */
export declare class Fdc3GridActionRaiseIntent extends FoundationElement implements ICellRendererComp {
    fdc3: FDC3;
    intentName: string;
    intentContextType: string;
    clickHandler(): Promise<void>;
    params: ICellRendererParams & ActionRendererParams;
    pendingAction: boolean;
    init(params: ICellRendererParams & ActionRendererParams): void;
    getGui(): HTMLElement;
    refresh(params: ICellRendererParams): boolean;
    isDisabled(data: any): boolean;
    get dataTestId(): string;
}

/**
 * @public
 */
export declare interface FDC3IntentResolution extends IntentResolution {
}

/**
 * @public
 */
export declare type FDC3Intents = Intents;

/**
 * A function that returns a Foundation Action Renderer for configuring the component with a DesignSystem that raises an fdc3 intent.
 *
 * @public
 * @remarks
 * HTML Element: \<foundation-grid-pro-action-raise-intent-renderer\>
 */
export declare const foundationGridProRaiseIntentActionRenderer: (overrideDefinition?: OverrideFoundationElementDefinition<    {
baseName: string;
styles: ElementStyles;
template: ViewTemplate<Fdc3GridActionRaiseIntent, any>;
}>) => FoundationElementRegistry<    {
baseName: string;
styles: ElementStyles;
template: ViewTemplate<Fdc3GridActionRaiseIntent, any>;
}, typeof Fdc3GridActionRaiseIntent>;

export { }
